# Engie's typescript components of the Fluid design system

[Fluid](https://www.engie.design/fluid-design-system/) is the Engie's design system, a collection of reusable components and styles used to build Engie's digital products.

Here is the package to benefit from Fluid's components and styles in your typescript project.

- [Versioning](#versioning)
- [Getting started](#getting-started)
  - [NPM installation](#npm-installation)
  - [CDN installation](#cdn-installation)
- [Documentation and usage](#documentation-and-usage)
- [Troubleshooting and feature requests](#troubleshooting-and-feature-requests)

## Versioning

⚠️ This package doesn't follow semantic versioning, breaking changes may be introduced in minor versions.

We recommend **fixing the version with the exact package version** to avoid breaking changes affecting your live website.
Moreover, we recommend checking the [CHANGELOG](https://github.tools.digital.engie.com/GBSEngieDigitalDesignSystem/fluid-design-system/blob/main/packages/fluid/CHANGELOG.md) before updating the package after a release.

## Getting started

This package can be installed directly with NPM or via CDN.

### NPM installation

You can install the package inside your application via [npmjs](https://www.npmjs.com/package/@engie-group/fluid-design-system):

```shell
# Using npm
npm install --save-exact @engie-group/fluid-design-system @engie-group/fluid-design-tokens

# Using pnpm
pnpm add --save-exact @engie-group/fluid-design-system @engie-group/fluid-design-tokens

# Using yarn
yarn add --save-exact @engie-group/fluid-design-system @engie-group/fluid-design-tokens
```

> ℹ️ If you use deprecated components or need the reboot.css, you will need to install and use some styles from the `@engie-group/fluid-4-deprecated` package.
>
> Please refer to the `@engie-group/fluid-4-deprecated` `README.md` for more information.
> 
> ```shell
> # Using npm
> npm install @engie-group/fluid-4-deprecated
> 
> # Using pnpm
> pnpm add @engie-group/fluid-4-deprecated
> 
> # Using yarn
> yarn add @engie-group/fluid-4-deprecated
> ```

#### Fonts and Icons

In order for the components to work properly, you need to include the Material Icons and Lato font in your project.

You should include them in your HTML `<head>`:

```html
<!-- Material icons, Lato font and Roboto Mono font -->
<link href="https://fonts.googleapis.com/css?family=Material+Icons|Lato:300,400,700,900|Roboto+Mono:300,400,700,900&display=swap" rel="stylesheet"/>
```

#### CSS

Component styling is based on CSS classes and some CSS variables (called design tokens).
In order for each component to be rendered as expected, you need to include CSS files as global stylesheet in your project.

You should include them in your HTML `<head>`:

```html
<!-- tokens.css = Styles to import tokens needed by components -->
<link href="<your-relative-path-to-node_modules>/@engie-group/fluid-design-tokens/lib/css/token.css" rel="stylesheet">
<!-- fluid-design-system.css = Styles of all components -->
<link href="<your-relative-path-to-node_modules>/@engie-group/fluid-design-system/lib/fluid-design-system.css" rel="stylesheet">
```

or in your JavaScript entry file :
  
```javascript
import '@engie-group/fluid-design-tokens/css';
import '@engie-group/fluid-design-system/css';
```

or in your CSS entry file :
  
```css
@import '@engie-group/fluid-design-tokens/css';
@import '@engie-group/fluid-design-system/css';
```

>ℹ️ We recommend including the Fluid Design System CSS before your own stylesheets to avoid any conflicts.

#### Javascript

Some components need JavaScript code to work properly.

When your DOM is rendered, dynamic components will need to be initialized to work properly.

To do so, you will have to initialize them either with a global script which will initialize all components or by initializing each component individually.

##### Global initialization

You can use the auto initializer script to initialize all components at once.

Add the following script near the end of your pages, right before the closing `</body>` tag:

```html
<script type="module" src="<your-relative-path-to-node_modules>/@engie-group/fluid-design-system/lib/auto-init.js"></script>
```

##### Individual initialization

You can also initialize each component individually in your JavaScript by calling the static `init` method of the component.

For example, to initialize all Select components on your page, you can use the following code:

```javascript
// In a JS file or script tag called right before the end of the body
import { Select } from '@engie-group/fluid-design-system';

Select.init();
```

### CDN installation

It's possible to use Fluid Design System via CDN. This is the recommended way to use Fluid if you don't have a build process or if you want to quickly test Fluid in a project.

As with the NPM installation, you will need to include some CSS and JavaScript files in your project. Installations are very similar.


#### Fonts and Icons

Nothing different here in comparison to the NPM installation, you still need to include the Material Icons and Lato font in your project.

You should include them in your HTML `<head>`:

```html
<!-- Material icons, Lato font and Roboto Mono font -->
<link href="https://fonts.googleapis.com/css?family=Material+Icons|Lato:300,400,700,900|Roboto+Mono:300,400,700,900&display=swap" rel="stylesheet"/>
```

#### CSS

Component styling is based on CSS classes and some CSS variables (called design tokens).
In order for each component to be rendered as expected, you need to include CSS files as global stylesheet in your project.

You should include them in your HTML `<head>`:

```html
<!-- tokens.css = Styles to import tokens needed by components -->
<link href="https://cdn.jsdelivr.net/npm/@engie-group/fluid-design-tokens@<VERSION>/lib/css/token.css" rel="stylesheet">
<!-- fluid-design-system.css = Styles of all components -->
<link href="https://cdn.jsdelivr.net/npm/@engie-group/fluid-design-system@<VERSION>/lib/fluid-design-system.css" rel="stylesheet">
```

>ℹ️ We recommend including the Fluid Design System CSS before your own stylesheets to avoid any conflicts.

> ℹ️ If you use deprecated components or need the reboot.css, you will need to install and use some styles from the `@engie-group/fluid-4-deprecated` package.

#### Javascript

Some components need JavaScript code to work properly.

To access components in your code we export a global `NJ` constant that contains all components.
To make it available, you will have to set this script before using any component:

```html
<script type="module" src="https://cdn.jsdelivr.net/npm/@engie-group/fluid-design-system@<VERSION>/lib/fluid-design-system.js"></script>
```

When your DOM is rendered, dynamic components will need to be initialized to work properly.

To do so, you will have to initialize them either with a global script which will initialize all components or by initializing each component individually.

##### Global initialization

You can use the auto initializer script to initialize all components at once.

Add the following script near the end of your pages, right before the closing `</body>` tag:

```html
<script type="module" src="https://cdn.jsdelivr.net/npm/@engie-group/fluid-design-system@<VERSION>/lib/auto-init.js"></script>
```

##### Individual initialization

You can also initialize each component individually in your JavaScript by calling the static `init` method of the component.

For example, to initialize all Select components on your page, you can use the following code:

```javascript
// In a JS file or script tag called right before the end of the body
NJ.Select.init();
```

## Documentation and usage

For a better comprehension of the components and their usage, we recommend checking our [Storybook](https://fluid.design.digital.engie.com/fluid-design-system/index.html) documentation.

For Fluid overall documentation, you can check our [Fluid documentation](https://www.engie.design/fluid-design-system/).

If you have correctly followed the installation steps, you should be able to use Fluid components in your project.

```html
<body>
  <!-- basic Fluid button component -->
  <button type="button" class="nj-btn">Fluid button</button>
  
  <!-- basic Fluid select component -->
  <div class="nj-form-item nj-form-item--select">
    <div class="nj-form-item__field-wrapper">
      <select class="nj-form-item__field" id="exampleSelect">
        <optgroup label="Group 1">
          <option>Item 1</option>
          <option>Item 2</option>
        </optgroup>
        <optgroup label="Group 2">
          <option>Item 3</option>
          <option>Item 4</option>
          <option>Item 5</option>
        </optgroup>
      </select>
      <label for="exampleSelect" class="nj-form-item__label">Example</label>
      <span aria-hidden="true" class="nj-form-item__icon material-icons">keyboard_arrow_down</span>
    </div>
  </div>
  <script type="module" src="<your-relative-path-to-node_modules>/@engie-group/fluid-design-system/lib/auto-init.js"></script>
</body>
```

## Troubleshooting and feature requests

If you encounter any issues, or you want any component or feature to be implemented, please create an issue or a feature request on our [GitHub repository](https://github.tools.digital.engie.com/GBSEngieDigitalDesignSystem/fluid-design-system/issues).
